"""Top-level package for geeagri."""

__author__ = """Krishnagopal Halder"""
__email__ = "geonextgis@gmail.com"
__version__ = "0.1.1"

from . import analysis
from . import extract
from . import preprocessing
